@@ -26,39 +26,30 @@
 #include "report.h"
 #include "version.h"
 
-int     flags         = 0;
-char *  progname      = "a.out";
-char *  database_file = LIBDIR "/rats.xml";
-char *  cdatabase_file = LIBDIR "/rats-c.xml";
-char *  pydatabase_file = LIBDIR "/rats-python.xml";
-
-char *default_files[] = { LIBDIR "/rats.xml",
-                          LIBDIR "/rats-c.xml",
-                          LIBDIR "/rats-python.xml",
-                          LIBDIR "/rats-perl.xml"
-                        };
-
-
-int 	forcelang	= 0;
-int	dbloaded	= 0;
-
+int     flags     = 0;
+int     forcelang = 0;
+char *  progname  = "a.out";
 
+char *default_files[] =
+{
+    LIBDIR "/rats.xml",
+    LIBDIR "/rats-c.xml",
+    LIBDIR "/rats-python.xml",
+    LIBDIR "/rats-perl.xml",
+    LIBDIR "/rats-php.xml"
+};
 
+static
 int string_compare(char *s1, char *s2) /* Case insensitive string compare */
 {
-
-
     for( ; tolower(*s1) == tolower(*s2); s1++, s2++)
         if (!*s1)
             return 0;
     return tolower(*s1) - tolower(*s2);
 }
 
-
-     
-    
 static
-int load_database(char *filename)
+int load_database(char *filename, int silent)
 {
     int         result;
     FILE *      fd;
@@ -67,7 +58,10 @@ int load_database(char *filename)
 
     if ((fd = fopen(filename, "r")) == (FILE *)NULL)
     {
-        fprintf(stderr, "Unable to open '%s' for reading.\n", filename);
+        if (!silent)
+        {
+            fprintf(stderr, "Unable to open '%s' for reading.\n", filename);
+        }
         return 0;
     }
 
@@ -87,22 +81,22 @@ void usage(void)
 {
     printf("RATS v%d.%d - Rough Auditing Tool for Security\n", VERSION_MAJOR, VERSION_MINOR);
     printf("Copyright 2001 by Secure Software Solutions\nhttp://www.securesw.com\n\n");
-    printf("usage: %s [-dhilrwx] name1 name2 ...\n\n", progname);
-    printf("    -a <name>       report any occurance of function 'name' in the source file(s)\n");
-    printf("    -d <filename>   specify an alternate vulnerability database.\n");
-    printf("    -h              display usage information (what you\'re reading)\n");
-    printf("    -i              report functions that accept external input\n");
-    printf("    -l <language>   Force the specified langauge to be used regardless of filename extension\n");
-    printf("    -r              include references that are not function calls\n");
-    printf("    -w <1,2,3>      set warning level (default %d)\n", warning_level);
-    printf("    -x              do not load default database (%s)\n", database_file);
+    printf("usage: %s [-adhilrwx] name1 name2 ... namen\n\n", progname);
+    printf("    -a <fun>       report any occurance of function 'fun' in the source file(s)\n");
+    printf("    -d <filename>  specify an alternate vulnerability database.\n");
+    printf("    -h             display usage information (what you\'re reading)\n");
+    printf("    -i             report functions that accept external input\n");
+    printf("    -l <language>  force the specified langauge to be used\n");
+    printf("    -r             include references that are not function calls\n");
+    printf("    -w <1,2,3>     set warning level (default %d)\n", warning_level);
+    printf("    -x             do not load default databases\n");
 }
 
 int main(int argc, char **argv)
 {
-    int i, load_default = 1;
-    Vuln_t *uservul = NULL;
-    Hash defh = NULL;
+    int     dbloaded = 0, i, load_default = 1;
+    Vuln_t  *uservul = NULL;
+    Hash    defh = NULL;
 
     progname = argv[0];
     while ((i = getopt(argc, argv, "a:d:hil:rw:x")) != -1)
@@ -110,15 +104,12 @@ int main(int argc, char **argv)
         switch (i)
         {
             case 'a':
-
                 if (!database)
-                {
-                  database = HashInit();
-                }
+                    database = HashInit();
                 if (!(defh = HashGet(database, "default")))
                 {
-                  defh = HashInit();
-                  HashInsert(database, defh, "default");
+                    defh = HashInit();
+                    HashInsert(database, defh, "default");
                 }
                 uservul = malloc(sizeof(Vuln_t));
                 InitVuln(uservul);
@@ -133,16 +124,12 @@ int main(int argc, char **argv)
  
                 HashInsert(defh, uservul, optarg);
                 if (!defaultdb)
-                  defaultdb = HashGet(database, "default");
+                    defaultdb = HashGet(database, "default");
                 break;
 
-                    
-            
             case 'd':
-                if (load_database(optarg))
-                {
-                  dbloaded++;
-                }
+                if (load_database(optarg, 0))
+                    dbloaded++;
                 break;
 
             case 'h':
@@ -190,9 +177,10 @@ int main(int argc, char **argv)
     {
         /* Load the vulnerability database into memory */
         int i;
-        for (i=0; i < sizeof(default_files)/sizeof(char *); i++)
+
+        for (i = 0;  i < sizeof(default_files) / sizeof(char *);  i++)
         {
-            if (load_database(default_files[i]))
+            if (load_database(default_files[i], 1))
                 dbloaded++;
         }
     }
@@ -203,6 +191,7 @@ int main(int argc, char **argv)
         exit(1);
         return 1;
     }
+
     if (optind >= argc)
     {
         process_file("<stdin>", stdin, forcelang);
@@ -213,6 +202,7 @@ int main(int argc, char **argv)
         {
             char *  filename;
             FILE *  fd;
+
             filename = argv[optind++];
             if ((fd = fopen(filename, "r")) == (FILE *)NULL)
             {
